@@ -2,7 +2,7 @@ from concurrent.futures.process import _threads_wakeups
 import enum
 import json
 import time
-from datetime import datetime
+from datetime import datetime, timedelta
 
 from ruamel.yaml import YAML
 
@@ -419,6 +419,19 @@ class _WiserOnOffSchedule(_WiserSchedule):
         """
         return self._device_type_ids
 
+    @property
+    def next_on(self):
+        """
+        Get date and time of next on event
+        """
+        
+
+    @property
+    def next_off(self):
+        """
+        Get date and time of next off event
+        """
+
     def assign_schedule(self, device_ids: list, include_current: bool = True) -> bool:
         """
         Assign schedule to devices
@@ -465,10 +478,10 @@ class _WiserOnOffSchedule(_WiserSchedule):
                 {
                     TEXT_TIME: (
                         datetime.strptime(
-                            format(abs(day_schedule[i]), "04d"), "%H%M"
+                            format(abs(day_schedule[i] if abs(day_schedule[i]) < 2400 else 0), "04d"), "%H%M"
                         )
                     ).strftime("%H:%M"),
-                    (TEXT_SETPOINT if generic_setpoint else TEXT_STATE): TEXT_ON if day_schedule[i] > 0 else TEXT_OFF,
+                    (TEXT_SETPOINT if generic_setpoint else TEXT_STATE): TEXT_ON if day_schedule[i] == abs(day_schedule[i]) else TEXT_OFF,
                 }
             )
         return sorted(schedule_set_points, key=lambda t: t['Time'])
@@ -485,10 +498,11 @@ class _WiserOnOffSchedule(_WiserSchedule):
             try:
                 if self._is_valid_time(entry.get("Time")):
                     time = int(str(entry.get("Time")).replace(":", ""))
+                    time = time if time != 0 else 2400
                 else:
                     time = 0
                 if entry.get("State", entry.get(TEXT_SETPOINT)).title() == TEXT_OFF:
-                    time = 0 - int(time)
+                    time = -abs(time) if time != 0 else -2400
             except Exception as ex:
                 _LOGGER.debug(ex)
                 time = 0
@@ -655,6 +669,23 @@ class _WiserScheduleNext:
         t = f'{self._data.get("Time", 0):04}'
         return datetime.strptime(t[:2] + ':' + t[-2:], '%H:%M').time()
 
+    @property
+    def datetime(self) -> datetime:
+        """Get the next entry date time"""
+        try:
+            next_schedule_day = (WEEKDAYS + WEEKENDS).index(self.day)
+            next_schedule_time = self.time
+            current_day = datetime.today().weekday()
+            current_time = datetime.now().time()
+            
+            # If next day or time on earlier weekday, add week to date
+            days_diff = next_schedule_day - current_day
+            days_diff = days_diff if days_diff > 0 or days_diff == 0 and next_schedule_time >= current_time  else days_diff + 7
+            next_date = datetime.today() + timedelta(days = days_diff)
+            return next_date.replace(hour=self.time.hour, minute=self.time.minute, second=0, microsecond=0)
+        except:
+            return None
+
     @property
     def setting(self) -> str:
         """Get the next entry setting - temp for heating, state for on/off devices"""
